EnvLine

Struct EnvLine 

pub struct EnvLine { /* private fields */ }
A classified Docker env-file line.

Implementations

Source

impl EnvLine

pub fn parse(value: impl AsRef<str>) -> Result<EnvLine, EnvParseError>

Parses an env-file line.

pub fn original(&self) -> &str

Returns the original line text.

pub const fn kind(&self) -> EnvLineKind

Returns the line kind.

pub const fn variable(&self) -> Option<&EnvVar>

Returns the parsed variable pair when this is a variable line.

pub fn key(&self) -> Option<&str>

Returns the parsed key when this is a variable line.

pub fn value(&self) -> Option<&str>

Returns the parsed value when this is a variable line.